==> flutter_catalogue_widgets-0.0.15.tar.gz: lib/custom-drawer.dart <==
/*
Description:

Displays a drawer commonly utilized with the Scaffold.drawer property. The child of the drawer is typically a ListView whose first child is a DrawerHeader that shows an image , title , subtitle about the current user.
The user profile followed by a ListTile, consisting of a leading icon and title.

Imports:
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';
import 'custom-drawer.dart';

Usage:

A list of DrawerListItems class is used to define the drawer items each listTile consisting of a leading Icon & Text.

DrawerHeaderParameters class is used to define the headerColor,listbgColor,title,subtitle,imagepath, imageType('Network' for a network imagepath or 'Asset' for an asset imagepath)

- Defining the callback and Drawer objects
  List<DrawerListItems> drawerList = [
      DrawerListItems(Icon(Icons.account_circle), Text("Account details")),
      DrawerListItems(Icon(Icons.history), Text("Order History")),
      DrawerListItems(Icon(Icons.account_balance_wallet), Text("Wallet")),
      DrawerListItems(Icon(Icons.cancel), Text("Logout")),

    ];

      DrawerHeaderParameters user1= new DrawerHeaderParameters(subtitle: 'abc@xyz.com',title: 'Account Name',imageType: "Asset",imagepath:'images/logo.png' ,headerColor:Colors.white);





    onclickDrawer(int nIndex) {
      print(nIndex);
    }
- Object call for the widget


   drawer: CustomDrawer(drawerList,onclickDrawer,user1),


Author:
Gautami Yeole
*/
import 'package:flutter/material.dart';
import 'theme.dart';
import 'package:flutter_catalogue_widgets/consts.dart' as con;
import 'package:flutter_catalogue_widgets/widget-classesUsed.dart';

// ignore: must_be_immutable
class CustomDrawer extends StatefulWidget {
  List<DrawerListItems> prod = [];
  final void Function(int) callback;
  final DrawerHeaderParameters userObject;

  CustomDrawer(this.prod, this.callback, this.userObject);

  List<DrawerListItems> defaultdrawerList = [
    DrawerListItems(con.drawerIcon1, con.drawerText1),
    DrawerListItems(con.drawerIcon2, con.drawerText2),
    DrawerListItems(con.drawerIcon3, con.drawerText3),
    DrawerListItems(con.drawerIcon4, con.drawerText4),
  ];

  DrawerHeaderParameters defaultuser = new DrawerHeaderParameters(
      title: con.userEmail,
      subtitle: con.userName,
      imageType: con.Network,
      imagepath: con.networkImage3,
      headerColor: mediumGreyThemeData().primaryColor,
      listbgColor: mediumGreyThemeData().canvasColor);

//passing the Products collection and callback function from the container

  @override
  State<StatefulWidget> createState() {
    if (prod == null && userObject == null) {
      return _StatecustomDrawer(defaultdrawerList, null, defaultuser);
    }

    return _StatecustomDrawer(this.prod, this.callback, this.userObject);
  }
}

class _StatecustomDrawer extends State<CustomDrawer> {
  List<DrawerListItems> prod = [];
  final void Function(int) callback;
  DrawerHeaderParameters userObject; //callback function with Function method
  _StatecustomDrawer(this.prod, this.callback,
      this.userObject); //passing the Products collection and callback function from the container

  @override
  Widget build(BuildContext context) {
    return Drawer(child: _leftnav(prod));
  }

  Widget _useraccount(DrawerHeaderParameters luseraccount) {
    ImageProvider image;
    if(luseraccount.imageType == "Asset"){
      image=(luseraccount.imagepath == null) ? NetworkImage("http://obdskopje.com.mk/assets/imgs/img_placeholder.png") : AssetImage(luseraccount.imagepath);
    }

    else if(luseraccount.imageType == "Network"){
      image=(luseraccount.imagepath == null) ? NetworkImage("http://obdskopje.com.mk/assets/imgs/img_placeholder.png") : NetworkImage(luseraccount.imagepath);

    }

    else{
      image = NetworkImage("http://obdskopje.com.mk/assets/imgs/img_placeholder.png");
    }

    return UserAccountsDrawerHeader(
        decoration: BoxDecoration(
            color: (luseraccount.headerColor == null)
                ? mediumGreyThemeData().scaffoldBackgroundColor
                : luseraccount.headerColor),
        accountName: Text(
          (luseraccount.title != null)
              ? luseraccount.title
              : con.Drawer_username,
          style: TextStyle(
            fontSize: (luseraccount.fontSize == null)
                ? con.fontMedium
                : luseraccount.fontSize,
            fontWeight: (luseraccount.fontWeight == null)
                ? con.bold
                : luseraccount.fontWeight,
            color: (luseraccount.fontColor == null)
                ? mediumGreyThemeData().scaffoldBackgroundColor
                : luseraccount.fontColor,
            fontFamily: (luseraccount.fontFamily == null)
                ? con.fontFamily
                : luseraccount.fontFamily,
          ),
        ),
        accountEmail: Text(
          (luseraccount.subtitle != null)
              ? luseraccount.subtitle
              : con.Drawer_email,
          style: TextStyle(
              fontSize: (luseraccount.fontSize == null)
                  ? con.fontMedium
                  : luseraccount.fontSize,
              fontWeight: (luseraccount.fontWeight == null)
                  ? con.bold
                  : luseraccount.fontWeight,
              color: (luseraccount.fontColor == null)
                  ? mediumGreyThemeData().scaffoldBackgroundColor
                  : luseraccount.fontColor,
              fontFamily: (luseraccount.fontFamily == null)
                  ? con.fontFamily
                  : luseraccount.fontFamily),
        ),
        currentAccountPicture: Container(
          decoration: BoxDecoration(
            shape: BoxShape.circle,
            image: DecorationImage(
              fit: BoxFit.fill,
              image: (luseraccount.imagepath != null)
                  ? image : NetworkImage("http://obdskopje.com.mk/assets/imgs/img_placeholder.png"),
            ),
          ),
        ));
  }

  List<Widget> leftnavitems(
      List<DrawerListItems> lnavigation, DrawerHeaderParameters luseraccount) {
    List<ListTile> leftitems = lnavigation
        .map((items) => (ListTile(
              leading:
                  (items.leading != null) ? items.leading : Icon(con.icon1),
              title: (items.title != null) ? items.title : Text(con.sampleText),
              onTap: () {
                callback(lnavigation.indexOf(items));
                Navigator.pop(context);
              },
            )))
        .toList();
    return leftitems;
  }

  Widget _leftnav(List<DrawerListItems> prod) {
    return Container(
      color: (userObject.listbgColor != null)
          ? userObject.listbgColor
          : Theme.of(context).accentColor,
      child: ListView(
        children: <Widget>[
          _useraccount(userObject),
          Column(
            children: leftnavitems(prod, userObject),
          )
        ],
      ),
    );
  }
}

==> flutter_catalogue_widgets-0.0.16.tar.gz: lib/custom-drawer.dart <==
/*
Description:

Displays a drawer commonly utilized with the Scaffold.drawer property. The child of the drawer is typically a ListView whose first child is a DrawerHeader that shows an image , title , subtitle about the current user.
The user profile followed by a ListTile, consisting of a leading icon and title.

Imports:
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';
import 'package:flutter_catalogue_widgets/custom-drawer.dart';

Usage:

A list of DrawerListItems class is used to define the drawer items each listTile consisting of a leading Icon & Text.

DrawerHeaderParameters class is used to define the headerColor,listbgColor,title,subtitle,imagepath, imageType('Network' for a network imagepath or 'Asset' for an asset imagepath)

- Defining the callback and Drawer objects
  List<DrawerListItems> drawerList = [
      DrawerListItems(Icon(Icons.account_circle), Text("Account details")),
      DrawerListItems(Icon(Icons.history), Text("Order History")),
      DrawerListItems(Icon(Icons.account_balance_wallet), Text("Wallet")),
      DrawerListItems(Icon(Icons.cancel), Text("Logout")),

    ];

      DrawerHeaderParameters user1= new DrawerHeaderParameters(subtitle: 'abc@xyz.com',title: 'Account Name',imageType: "Asset",imagepath:'images/logo.png' ,headerColor:Colors.white);





    onclickDrawer(int nIndex) {
      print(nIndex);
    }
- Object call for the widget


   drawer: CustomDrawer(drawerList,onclickDrawer,user1),


Author:
Gautami Yeole
*/
import 'package:flutter/material.dart';
import 'package:flutter_catalogue_widgets/theme.dart';
import 'package:flutter_catalogue_widgets/consts.dart' as con;
import 'package:flutter_catalogue_widgets/widget-classesUsed.dart';

// ignore: must_be_immutable
class CustomDrawer extends StatefulWidget {
  List<DrawerListItems> prod = [];
  final void Function(int) callback;
  final DrawerHeaderParameters userObject;

  CustomDrawer(this.prod, this.callback, this.userObject);

  List<DrawerListItems> defaultdrawerList = [
    DrawerListItems(con.drawerIcon1, con.drawerText1),
    DrawerListItems(con.drawerIcon2, con.drawerText2),
    DrawerListItems(con.drawerIcon3, con.drawerText3),
    DrawerListItems(con.drawerIcon4, con.drawerText4),
  ];

  DrawerHeaderParameters defaultuser = new DrawerHeaderParameters(
      title: con.userEmail,
      subtitle: con.userName,
      imageType: con.Network,
      imagepath: con.networkImage3,
      headerColor: mediumGreyThemeData().primaryColor,
      listbgColor: mediumGreyThemeData().canvasColor);

//passing the Products collection and callback function from the container

  @override
  State<StatefulWidget> createState() {
    if (prod == null && userObject == null) {
      return _StatecustomDrawer(defaultdrawerList, null, defaultuser);
    }

    return _StatecustomDrawer(this.prod, this.callback, this.userObject);
  }
}

class _StatecustomDrawer extends State<CustomDrawer> {
  List<DrawerListItems> prod = [];
  final void Function(int) callback;
  DrawerHeaderParameters userObject; //callback function with Function method
  _StatecustomDrawer(this.prod, this.callback,
      this.userObject); //passing the Products collection and callback function from the container

  @override
  Widget build(BuildContext context) {
    return Drawer(child: _leftnav(prod));
  }

  Widget _useraccount(DrawerHeaderParameters luseraccount) {
    ImageProvider image;
    if(luseraccount.imageType == "Asset"){
      image=(luseraccount.imagepath == null) ? NetworkImage("http://obdskopje.com.mk/assets/imgs/img_placeholder.png") : AssetImage(luseraccount.imagepath);
    }

    else if(luseraccount.imageType == "Network"){
      image=(luseraccount.imagepath == null) ? NetworkImage("http://obdskopje.com.mk/assets/imgs/img_placeholder.png") : NetworkImage(luseraccount.imagepath);

    }

    else{
      image = NetworkImage("http://obdskopje.com.mk/assets/imgs/img_placeholder.png");
    }

    return UserAccountsDrawerHeader(
        decoration: BoxDecoration(
            color: (luseraccount.headerColor == null)
                ? mediumGreyThemeData().scaffoldBackgroundColor
                : luseraccount.headerColor),
        accountName: Text(
          (luseraccount.title != null)
              ? luseraccount.title
              : con.Drawer_username,
          style: TextStyle(
            fontSize: (luseraccount.fontSize == null)
                ? con.fontMedium
                : luseraccount.fontSize,
            fontWeight: (luseraccount.fontWeight == null)
                ? con.bold
                : luseraccount.fontWeight,
            color: (luseraccount.fontColor == null)
                ? mediumGreyThemeData().scaffoldBackgroundColor
                : luseraccount.fontColor,
            fontFamily: (luseraccount.fontFamily == null)
                ? con.fontFamily
                : luseraccount.fontFamily,
          ),
        ),
        accountEmail: Text(
          (luseraccount.subtitle != null)
              ? luseraccount.subtitle
              : con.Drawer_email,
          style: TextStyle(
              fontSize: (luseraccount.fontSize == null)
                  ? con.fontMedium
                  : luseraccount.fontSize,
              fontWeight: (luseraccount.fontWeight == null)
                  ? con.bold
                  : luseraccount.fontWeight,
              color: (luseraccount.fontColor == null)
                  ? mediumGreyThemeData().scaffoldBackgroundColor
                  : luseraccount.fontColor,
              fontFamily: (luseraccount.fontFamily == null)
                  ? con.fontFamily
                  : luseraccount.fontFamily),
        ),
        currentAccountPicture: Container(
          decoration: BoxDecoration(
            shape: BoxShape.circle,
            image: DecorationImage(
              fit: BoxFit.fill,
              image: (luseraccount.imagepath != null)
                  ? image : NetworkImage("http://obdskopje.com.mk/assets/imgs/img_placeholder.png"),
            ),
          ),
        ));
  }

  List<Widget> leftnavitems(
      List<DrawerListItems> lnavigation, DrawerHeaderParameters luseraccount) {
    List<ListTile> leftitems = lnavigation
        .map((items) => (ListTile(
              leading:
                  (items.leading != null) ? items.leading : Icon(con.icon1),
              title: (items.title != null) ? items.title : Text(con.sampleText),
              onTap: () {
                callback(lnavigation.indexOf(items));
                Navigator.pop(context);
              },
            )))
        .toList();
    return leftitems;
  }

  Widget _leftnav(List<DrawerListItems> prod) {
    return Container(
      color: (userObject.listbgColor != null)
          ? userObject.listbgColor
          : Theme.of(context).accentColor,
      child: ListView(
        children: <Widget>[
          _useraccount(userObject),
          Column(
            children: leftnavitems(prod, userObject),
          )
        ],
      ),
    );
  }
}
